@@ -218,11 +218,14 @@ static int create_accessor(grib_section* p, grib_action* act, grib_loader* h)
     hand = grib_handle_of_accessor(x);
     if (hand->use_trie) {
         id = grib_hash_keys_get_id(x->context->keys, act->name);
+        hand->accessors[id] = x;
 
-        if (hand->accessors[id] != x) {
-            /*x->same=hand->accessors[id];*/
-            hand->accessors[id] = x;
-        }
+        /*
+         if (hand->accessors[id] != x) {
+           x->same=hand->accessors[id];
+           hand->accessors[id] = x;
+         }
+        */
     }
 
     i = 0;
@@ -269,6 +272,8 @@ static void dump(grib_action* act, FILE* f, int lvl)
 
 static void xref(grib_action* act, FILE* f, const char* path)
 {
+    Assert(!"xref is disabled");
+#if 0
     grib_action_alias* a = (grib_action_alias*)act;
     if (a->target) {
         fprintf(f, "bless({name=>'%s', target=>'%s', path=>'%s'},'xref::alias'),\n", act->name, a->target, path);
@@ -280,6 +285,7 @@ static void xref(grib_action* act, FILE* f, const char* path)
         if (act->name_space)
             fprintf(f, "bless({name=>'%s.%s', path=>'%s'},'xref::unalias'),\n", act->name_space, act->name, path);
     }
+#endif
 }
 
 static void destroy(grib_context* context, grib_action* act)
