@@ -109,11 +109,11 @@ static int create_accessor(grib_section* p, grib_action* act, grib_loader* h)
     long val          = 0;
 
     if ((ret = grib_expression_evaluate_long(p->h, a->expression, &val)) != GRIB_SUCCESS) {
-        grib_context_log(p->h->context, GRIB_LOG_DEBUG, " List %s creating %d values unable to evaluate long \n", act->name, val);
+        grib_context_log(p->h->context, GRIB_LOG_DEBUG, "List %s creating %d values unable to evaluate long", act->name, val);
         return ret;
     }
 
-    grib_context_log(p->h->context, GRIB_LOG_DEBUG, " List %s creating %d values \n", act->name, val);
+    grib_context_log(p->h->context, GRIB_LOG_DEBUG, "List %s creating %d values", act->name, val);
 
     ga = grib_accessor_factory(p, act, 0, NULL);
     if (!ga)
@@ -167,7 +167,8 @@ static grib_action* reparse(grib_action* a, grib_accessor* acc, int* doit)
     long val = 0;
 
     if ((ret = grib_expression_evaluate_long(grib_handle_of_accessor(acc), self->expression, &val)) != GRIB_SUCCESS) {
-        grib_context_log(acc->context, GRIB_LOG_ERROR, " List %s creating %d values unable to evaluate long \n", acc->name, val);
+        grib_context_log(acc->context, GRIB_LOG_ERROR,
+                "List %s creating %ld values, unable to evaluate long", acc->name, val);
     }
 
     *doit = (val != acc->loop);
