@@ -334,15 +334,15 @@ static int apply_operators(grib_accessor* a)
     size_t size = 0, sizeAO = 0, iq = 0, numberOfDescriptors;
     size_t i = 0, j = 0, ielement = 0;
     int err                                                = 0;
-    char* missing                                          = "???";
+    const char* missing                                    = "???";
     long associatedFieldWidth                              = 0;
-    char* firstOrderStatisticsAbbreviation                 = "firstOrderStatistics";
-    char* differenceStatisticsAbbreviation                 = "differenceStatistics";
-    char* associatedFieldAbbreviation                      = "associatedField";
-    char* substitutedValueAbbreviation                     = "substitutedValue";
-    char* associatedFieldName                              = "associated field";
-    char* associatedFieldType                              = "long";
-    char* associatedFieldUnit                              = "CODE TABLE 31021";
+    const char* firstOrderStatisticsAbbreviation           = "firstOrderStatistics";
+    const char* differenceStatisticsAbbreviation           = "differenceStatistics";
+    const char* associatedFieldAbbreviation                = "associatedField";
+    const char* substitutedValueAbbreviation               = "substitutedValue";
+    const char* associatedFieldName                        = "associated field";
+    const char* associatedFieldType                        = "long";
+    const char* associatedFieldUnit                        = "CODE TABLE 31021";
     long associatedFieldDescriptor                         = 99999;
     long delayedReplication[MAX_DELAYED_REPLICATION_COUNT] = {0,};
     long delayedReplicationIndex[MAX_DELAYED_REPLICATION_COUNT] = {0,};
@@ -660,7 +660,7 @@ static int unpack_string_array(grib_accessor* a, char** val, size_t* len)
 
     if (*len < self->expandedAOSize) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, self->expandedAOSize);
+                         "Wrong size (%lu) for %s, it contains %lu values", *len, a->name, self->expandedAOSize);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
@@ -726,7 +726,7 @@ static int unpack_long(grib_accessor* a, long* val, size_t* len)
 
     if (*len < self->expandedAOSize) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, self->expandedAOSize);
+                         "Wrong size (%lu) for %s it contains %lu values", *len, a->name, self->expandedAOSize);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
@@ -784,7 +784,7 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
 
     if (*len < self->expandedAOSize) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, self->expandedAOSize);
+                         "Wrong size (%lu) for %s it contains %lu values", *len, a->name, self->expandedAOSize);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
