@@ -211,11 +211,29 @@ static void dump(grib_accessor* a, grib_dumper* dumper)
 
 static bufr_descriptors_array* do_expand(grib_accessor* a, bufr_descriptors_array* unexpanded, change_coding_params* ccp, int* err);
 
+#define BUFR_DESCRIPTORS_ARRAY_USED_SIZE(v) ((v)->n)
+#define SILENT 1
+
 #if MYDEBUG
 static int global_depth = -1;
-#endif
 
-#define BUFR_DESCRIPTORS_ARRAY_USED_SIZE(v) ((v)->n)
+static char* descriptor_type_name(int dtype)
+{
+    switch (dtype) {
+        case BUFR_DESCRIPTOR_TYPE_STRING:      return "string";
+        case BUFR_DESCRIPTOR_TYPE_LONG:        return "long";
+        case BUFR_DESCRIPTOR_TYPE_DOUBLE:      return "double";
+        case BUFR_DESCRIPTOR_TYPE_TABLE:       return "table";
+        case BUFR_DESCRIPTOR_TYPE_FLAG:        return "flag";
+        case BUFR_DESCRIPTOR_TYPE_UNKNOWN:     return "unknown";
+        case BUFR_DESCRIPTOR_TYPE_REPLICATION: return "replication";
+        case BUFR_DESCRIPTOR_TYPE_OPERATOR:    return "operator";
+        case BUFR_DESCRIPTOR_TYPE_SEQUENCE:    return "sequence";
+    }
+    Assert(!"bufr_descriptor_type_name failed");
+    return "unknown";
+}
+#endif
 
 static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_descriptors_array* expanded,
                      change_coding_params* ccp, int* err)
@@ -258,7 +276,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
-            printf("+++ pop  %06ld\n", u->code);
+            printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
 #endif
             /*this is to get the sequence elements of the sequence unexpanded[i] */
             *err = grib_set_long(hand, self->sequence, u->code);
@@ -273,7 +291,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 
             inner_unexpanded = grib_bufr_descriptors_array_new(c, DESC_SIZE_INIT, DESC_SIZE_INCR);
             for (i = 0; i < size; i++) {
-                vv               = grib_bufr_descriptor_new(self->tablesAccessor, v[i], err);
+                vv               = grib_bufr_descriptor_new(self->tablesAccessor, v[i], !SILENT, err);
                 inner_unexpanded = grib_bufr_descriptors_array_push(inner_unexpanded, vv);
             }
             grib_context_free(c, v);
@@ -300,7 +318,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
                 for (idepth = 0; idepth < global_depth; idepth++)
                     printf("\t");
-                printf("+++ pop  %06ld\n", u->code);
+                printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
                 for (idepth = 0; idepth < global_depth; idepth++)
                     printf("\t");
                 printf("+++ push %06ld\n", u->code);
@@ -324,7 +342,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
                     for (idepth = 0; idepth < global_depth; idepth++)
                         printf("\t");
-                    printf("+++ pop  %06ld\n", u0->code);
+                    printf("+++ pop  %06ld [%s]\n", u0->code, descriptor_type_name(u0->type));
 #endif
                 }
                 inner_expanded = do_expand(a, inner_unexpanded, ccp, err);
@@ -349,7 +367,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
                 for (idepth = 0; idepth < global_depth; idepth++)
                     printf("\t");
-                printf("+++ pop  %06ld\n", u->code);
+                printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
 #endif
                 grib_bufr_descriptor_delete(u);
                 size = us->X * us->Y;
@@ -359,7 +377,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
                     for (idepth = 0; idepth < global_depth; idepth++)
                         printf("\t");
-                    printf("+++ pop  %06ld\n", ur[j]->code);
+                    printf("+++ pop  %06ld [%s]\n", ur[j]->code, descriptor_type_name(ur[j]->type));
 #endif
                 }
                 inner_unexpanded = grib_bufr_descriptors_array_new(c, DESC_SIZE_INIT, DESC_SIZE_INCR);
@@ -396,7 +414,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
             DESCRIPTORS_POP_FRONT_OR_RETURN(unexpanded, u);
             size = 1;
             if (ccp->associatedFieldWidth && u->X != 31) {
-                bufr_descriptor* au = grib_bufr_descriptor_new(self->tablesAccessor, 999999, err);
+                bufr_descriptor* au = grib_bufr_descriptor_new(self->tablesAccessor, 999999, !SILENT, err);
                 au->width           = ccp->associatedFieldWidth;
                 grib_bufr_descriptor_set_scale(au, 0);
                 strcpy(au->shortName, "associatedField");
@@ -405,7 +423,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
                 for (idepth = 0; idepth < global_depth; idepth++)
                     printf("\t");
-                printf("+++ push %06ld (%ld %ld %ld)", au->code, au->scale, au->reference, au->width);
+                printf("+++ push %06ld (s=%ld r=%ld w=%ld)", au->code, au->scale, au->reference, au->width);
 #endif
                 grib_bufr_descriptors_array_push(expanded, au);
                 size++;
@@ -413,11 +431,11 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
-            printf("+++ pop  %06ld\n", u->code);
+            printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
-            printf("+++ push %06ld [type=%d] (%ld %ld %ld)", u->code,
-                   u->type, u->scale, u->reference, u->width);
+            printf("+++ push %06ld [%s] (s=%ld r=%ld w=%ld)",
+                   u->code, descriptor_type_name(u->type), u->scale, u->reference, u->width);
 #endif
             if (u->type != BUFR_DESCRIPTOR_TYPE_FLAG &&
                 u->type != BUFR_DESCRIPTOR_TYPE_TABLE &&
@@ -438,7 +456,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
                 u->width = ccp->newStringWidth;
             }
 #if MYDEBUG
-            printf("->(%ld %ld %ld)\n", u->scale, u->reference, u->width);
+            printf("->(s=%ld r=%ld w=%ld)\n", u->scale, u->reference, u->width);
 #endif
             grib_bufr_descriptors_array_push(expanded, u);
             break;
@@ -448,7 +466,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
-            printf("+++ pop  %06ld\n", u->code);
+            printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
 #endif
             switch (us->X) {
                 case 1:
@@ -505,7 +523,7 @@ static void __expand(grib_accessor* a, bufr_descriptors_array* unexpanded, bufr_
 #if MYDEBUG
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
-            printf("+++ pop  %06ld\n", u->code);
+            printf("+++ pop  %06ld [%s]\n", u->code, descriptor_type_name(u->type));
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
             printf("+++ push %06ld\n", u->code);
@@ -568,7 +586,7 @@ static bufr_descriptors_array* do_expand(grib_accessor* a, bufr_descriptors_arra
             for (idepth = 0; idepth < global_depth; idepth++)
                 printf("\t");
             printf("==  %-6d== %06ld ", i, xx->code);
-            printf("%ld %ld %ld", xx->scale, xx->reference, xx->width);
+            printf("s=%ld r=%ld w=%ld", xx->scale, xx->reference, xx->width);
             printf("\n");
         }
         for (idepth = 0; idepth < global_depth; idepth++)
@@ -658,8 +676,12 @@ static int expand(grib_accessor* a)
     unexpanded_copy      = grib_bufr_descriptors_array_new(c, unexpandedSize, DESC_SIZE_INCR);
     operator206yyy_width = 0;
     for (i = 0; i < unexpandedSize; i++) {
-        bufr_descriptor* aDescriptor1 = grib_bufr_descriptor_new(self->tablesAccessor, u[i], &err);
-        bufr_descriptor* aDescriptor2 = grib_bufr_descriptor_new(self->tablesAccessor, u[i], &err);
+        bufr_descriptor *aDescriptor1, *aDescriptor2;
+        /* ECC-1274: clear error and only issue msg once */
+        err = 0;
+        aDescriptor1 = grib_bufr_descriptor_new(self->tablesAccessor, u[i], SILENT, &err);
+        err = 0;
+        aDescriptor2 = grib_bufr_descriptor_new(self->tablesAccessor, u[i], !SILENT, &err);
 
         /* ECC-433: Operator 206YYY */
         if (aDescriptor1->F == 2 && aDescriptor1->X == 6) {
@@ -740,7 +762,7 @@ static int unpack_double(grib_accessor* a, double* val, size_t* len)
         expandedSize = BUFR_DESCRIPTORS_ARRAY_USED_SIZE(self->expanded);
         if (*len < expandedSize) {
             grib_context_log(a->context, GRIB_LOG_ERROR,
-                             " wrong size (%ld) for %s it contains %d values ", *len, a->name, expandedSize);
+                             "Wrong size (%ld) for %s, it contains %lu values", *len, a->name, expandedSize);
             *len = 0;
             return GRIB_ARRAY_TOO_SMALL;
         }
@@ -767,7 +789,7 @@ static int unpack_long(grib_accessor* a, long* val, size_t* len)
 
     if (*len < rlen) {
         grib_context_log(a->context, GRIB_LOG_ERROR,
-                         " wrong size (%ld) for %s it contains %d values ", *len, a->name, rlen);
+                         "Wrong size (%ld) for %s, it contains %lu values", *len, a->name, rlen);
         *len = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
