@@ -205,7 +205,8 @@ static int unpack_string(grib_accessor* a, char* val, size_t* len)
     length = string_length(a);
 
     if (len[0] < length + 1) {
-        grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name, a->length + 1);
+        grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%lu) for %s, it contains %ld values",
+                len[0], a->name, a->length + 1);
         len[0] = 0;
         return GRIB_ARRAY_TOO_SMALL;
     }
@@ -255,7 +256,7 @@ static int unpack_long(grib_accessor* a, long* v, size_t* len)
     *v = strtol(val, &last, 10);
     /* if (*last) {err=GRIB_WRONG_CONVERSION;} */
 
-    return err;
+    return GRIB_SUCCESS;
 }
 
 static int unpack_double(grib_accessor* a, double* v, size_t* len)
