@@ -148,8 +148,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
     size_t nvalues      = 0;
     grib_iterator* iter = NULL;
     double lat = 0, lon = 0;
-    long iradius;
-    double radius;
+    double radiusInKm;
     int ilat = 0, ilon = 0;
     get_reduced_row_proc get_reduced_row_func = &grib_get_reduced_row;
 
@@ -164,14 +163,8 @@ static int find(grib_nearest* nearest, grib_handle* h,
         return ret;
     nearest->values_count = nvalues;
 
-    if (grib_is_missing(h, self->radius, &ret)) {
-        grib_context_log(h->context, GRIB_LOG_DEBUG, "Key '%s' is missing", self->radius);
-        return ret ? ret : GRIB_GEOCALCULUS_PROBLEM;
-    }
-
-    if ((ret = grib_get_long(h, self->radius, &iradius)) != GRIB_SUCCESS)
+    if ((ret = grib_nearest_get_radius(h, &radiusInKm)) != GRIB_SUCCESS)
         return ret;
-    radius = ((double)iradius) / 1000.0;
 
     /* Compute lat/lon info, create iterator etc if it's the 1st time or different grid.
      * This is for performance: if the grid has not changed, we only do this once
@@ -421,7 +414,7 @@ static int find(grib_nearest* nearest, grib_handle* h,
         kk = 0;
         for (jj = 0; jj < 2; jj++) {
             for (ii = 0; ii < 2; ii++) {
-                self->distances[kk] = geographic_distance_spherical(radius, inlon, inlat,
+                self->distances[kk] = geographic_distance_spherical(radiusInKm, inlon, inlat,
                                                                     self->lons[self->k[kk]], self->lats[self->j[jj]]);
                 kk++;
             }
