@@ -7,7 +7,7 @@
 # In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
-. ./include.sh
+. ./include.ctest.sh
 set -u
 
 label="grib2_templates"
@@ -15,6 +15,7 @@ label="grib2_templates"
 temp1=temp1.$label.grib2
 temp2=temp2.$label.grib2
 temp=temp.$label.grib2
+tempFilt=temp.$label.filt
 sample2=$ECCODES_SAMPLES_PATH/GRIB2.tmpl
 
 
@@ -27,9 +28,15 @@ grib_check_key_equals $temp totalNumberOfQuantiles,quantileValue '2 0'
 
 # Template 4.88
 # -------------
-# TODO: Add tablesVersion later...
-$tools_dir/grib_set -s productDefinitionTemplateNumber=88,numberOfForecastsUsedInLocalTime=1 $sample2 $temp
+$tools_dir/grib_set -s tablesVersion=27,productDefinitionTemplateNumber=88,numberOfForecastsUsedInLocalTime=1 $sample2 $temp
 grib_check_key_equals $temp localTimeMethod 255
+# ECC-1255: check transient is_localtime is not an array
+cat > $tempFilt <<EOF
+ print "is_localtime=[is_localtime]";
+EOF
+result=`${tools_dir}/grib_filter $tempFilt $temp`
+[ "$result" = "is_localtime=1" ]
+
 
 # Templates 4.76 -> 4.79, 4.80 -> 4.83
 # -------------------------------------
@@ -112,4 +119,4 @@ $tools_dir/grib_set -s tablesVersion=26,productDefinitionTemplateNumber=85 $samp
 $tools_dir/grib_compare -b productDefinitionTemplateNumber $temp1 $temp2
 
 
-rm -f $temp $temp1 $temp2
+rm -f $temp $temp1 $temp2 $tempFilt
